@@ -121,6 +121,12 @@ class Parser(object):
 
     @staticmethod
     def encode_payload(packets, supports_binary=True):
+        """
+
+        :param packets: (list, tuple)
+        :param supports_binary: bool
+        :return:
+        """
         if supports_binary is True:
             return Parser.encode_payload_as_binary(packets)
 
@@ -135,7 +141,7 @@ class Parser(object):
             encoded = Parser.encode_packet(packet, supports_binary)
             out_buffer += '{0}:{1}'.format(str(len(encoded)), encoded)
 
-        return out_buffer
+        return str(out_buffer)
 
     @staticmethod
     def decode_payload(data):
@@ -150,8 +156,10 @@ class Parser(object):
             length_str = ''
             total_length = len(data)
 
-            for i in xrange(0, len(data)):
+            i = 0
+            while i < total_length:
                 ch = data[i]
+                i += 1
                 if ch != ':':
                     length_str += ch
                 else:
@@ -159,7 +167,7 @@ class Parser(object):
                         yield (Parser.error_packet, 0, 1)
 
                     length = int(length_str)
-                    message = data[i+1: i+1+length]
+                    message = data[i: i+length]
 
                     if len(message) != length:
                         yield (Parser.error_packet, 0, 1)
@@ -168,6 +176,7 @@ class Parser(object):
                         packet = Parser.decode_packet(message)
                         yield (packet, i + length, total_length)
 
+                    i += length
                     length_str = ''
 
             if length_str != '':
